%define major      2
%define libname    %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d

%bcond_with syswebrtc
%bcond_without python

Name:           pjproject
Version:        2.14.1
Release:        %mkrel 2
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
License:        GPLv2+
URL:            https://www.pjsip.org/
Source0:        https://github.com/pjsip/pjproject/archive/%{version}/pjproject-%{version}.tar.gz

# Tell the build system not to use most of the third_party directory
Patch101:       0101-Tell-the-build-system-not-to-use-most-of-the-third_p.patch
# Keep the .pc file clean
# see https://bugzilla.redhat.com/show_bug.cgi?id=728302#c66
Patch102:       0102-Keep-the-.pc-file-clean.patch
# Fix ARMv7 endianness
Patch104:       0104-Fix-ARMv7-endianness.patch
# Add aarch64 detection
Patch105:       0105-Add-aarch64-detection.patch
# Don't use SSE2 if it is not available
Patch108:       0108-Don-t-use-SSE2-if-it-is-not-available.patch
# Fix LDFLAGS usage
Patch131:       0131-Fix-LDFLAGS-usage.patch

BuildRequires:  git-core
BuildRequires:  gsm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(portaudio-2.0)
%if %{with python}
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
%endif
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)

%description
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA


%package -n     %{libname}
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
%if ! %{with python}
Obsoletes:      python3-pjsua2 < %{version}-%{release}
%endif

%description -n %{libname}
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA

This package contains the shared library part of ccrtp.


%package -n     %{libnamedev}
Summary:        Development files to use pjproject
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libnamedev}
Header information for:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library


%package -n     pjsua
Summary:        command line SIP user agent
Group:          System/Libraries

%description -n pjsua
pjsua is an open source command line SIP user agent (softphone)
that is used as the reference implementation for PJSIP, PJNATH, and PJMEDIA.
Despite its simple command line appearance, it does pack many features!


%package -n     python3-pjsua2
Summary:        PJSUA2 Python Module
Group:          Development/Python
Provides:       python-pjsua = %{version}-%{release}
Provides:       python-pjsua2 = %{version}-%{release}

%description -n python3-pjsua2
The PJSUA2 for Python Module is an object oriented Python
wrapper/abstraction/modules for PJSUA API.

%prep
%autosetup -p1 -Sgit_am

# make sure we don't bundle these third-party libraries
# (They're excluded through ./configure, but this is an
# additional safety net)
rm -rf third_party/BaseClasses
rm -rf third_party/bdsound
rm -rf third_party/bin
rm -rf third_party/g7221
rm -rf third_party/gsm
rm -rf third_party/milenage
rm -rf third_party/mp3
rm -rf third_party/portaudio
rm -rf third_party/resample
rm -rf third_party/speex
rm -rf third_party/srtp
rm -rf third_party/ilbc
%if %{with syswebrtc}
rm -rf third_party/webrtc
%endif
rm -rf third_party/build/baseclasses
rm -rf third_party/build/g7221
rm -rf third_party/build/gsm
rm -rf third_party/build/milenage
rm -rf third_party/build/portaudio/src
rm -rf third_party/build/resample
rm -rf third_party/build/samplerate
rm -rf third_party/build/speex
rm -rf third_party/build/srtp
rm -rf third_party/build/ilbc
%if %{with syswebrtc}
rm -rf third_party/build/webrtc
%endif

%build
# Regenerate aconfigure for Patch8
autoconf aconfigure.ac > aconfigure

# We're building without audio or video support, as Asterisk isn't using
# that functionality, and it made it easier to ensure that we don't
# bundle any unnecessary libraries.  Please contact me if your project
# needs this support, and I'll re-enable it
export CFLAGS="-DPJ_HAS_IPV6=1 -DNDEBUG ${ARCHFLAGS} %{optflags}"

%configure \
	--enable-shared        \
	--with-external-gsm    \
	--with-external-pa     \
	--with-external-speex  \
	--with-external-srtp   \
%if %{with syswebrtc}
	--with-external-webrtc \
%endif
	--disable-opencore-amr \
	--disable-resample     \
	--disable-sound        \
	--disable-video        \
	--disable-v4l2         \
	--disable-ilbc-codec   \
	--disable-libyuv       \
	--disable-g7221-codec

%make_build dep
%make_build

%if %{with python}
sed -i 's|LANG = python java|LANG = python|' pjsip-apps/src/swig/Makefile
%__make -C pjsip-apps/src/swig V=1 VERBOSE=1
pushd pjsip-apps/src/swig/python
    %pyproject_wheel
popd
%endif

%install
%make_install

%if %{with python}
pushd pjsip-apps/src/swig/python
    %pyproject_install
popd
%endif

install -p -D -m 0755 pjsip-apps/bin/pjsua-* %{buildroot}%{_bindir}/pjsua

# Remove the static libraries, as they aren't wanted
find %{buildroot} -type f -name "*.a" -delete


%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{libnamedev}
%doc README.md SECURITY.md
%{_libdir}/lib*.so
%{_includedir}/pj++/
%{_includedir}/pj/
%{_includedir}/pjlib-util/
%{_includedir}/pjmedia-audiodev/
%{_includedir}/pjmedia-codec/
%{_includedir}/pjmedia-videodev/
%{_includedir}/pjmedia/
%{_includedir}/pjnath/
%{_includedir}/pjsip-simple/
%{_includedir}/pjsip-ua/
%{_includedir}/pjsip/
%{_includedir}/pjsua-lib/
%{_includedir}/pjsua2/
%{_includedir}/*.h
%{_includedir}/*.hpp
%{_libdir}/pkgconfig/libpjproject.pc

%if %{with python}
%files -n python3-pjsua2
%doc pjsip-apps/src/python/samples
%{python3_sitearch}/_pjsua2*.so
%{python3_sitearch}/pjsua2-%{version}.dist-info/
%{python3_sitearch}/pjsua2.py*
%{python3_sitearch}/__pycache__/pjsua2*.pyc
%endif

%files -n pjsua
%doc README.md
%{_bindir}/pjsua


%changelog
* Tue Mar 04 2025 wally <wally> 2.14.1-2.mga10
+ Revision: 2160417
- rebuild for python3.13

* Thu Mar 14 2024 daviddavid <daviddavid> 2.14.1-1.mga10
+ Revision: 2049867
- new version: 2.14.1
- remove merged upstream patches
- re-enable python3 module called now pjsua2

* Sat Jan 21 2023 wally <wally> 2.13-1.mga9
+ Revision: 1934685
- new version 2.13 with latest fixes from upstream git
  - including fixes for CVE-2022-23537 and CVE-2022-23547

* Wed Apr 06 2022 wally <wally> 2.12-1.mga9
+ Revision: 1846540
- new version 2.12

* Fri Apr 01 2022 umeabot <umeabot> 2.11.1-3.mga9
+ Revision: 1838975
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.11.1-2.mga9
+ Revision: 1747574
- rebuild for openssl 3.0.0

* Sun Aug 01 2021 wally <wally> 2.11.1-1.mga9
+ Revision: 1738453
- new version 2.11.1 to fix CVE-2021-32686 (mga#29317)

* Sun May 30 2021 wally <wally> 2.11-1.mga9
+ Revision: 1728896
- new version 2.11
- disable patches from jami-daemon for now

* Fri Dec 25 2020 wally <wally> 2.10-5.mga8
+ Revision: 1663705
- update patches from jami-daemon

* Sun Oct 25 2020 wally <wally> 2.10-4.mga8
+ Revision: 1639355
- rebuild with new libsrtp2

* Sat May 09 2020 wally <wally> 2.10-3.mga8
+ Revision: 1581929
- move python obsoletes to better place

* Thu May 07 2020 wally <wally> 2.10-2.mga8
+ Revision: 1581556
- obsolete python pkg if it's not built

* Sat May 02 2020 wally <wally> 2.10-1.mga8
+ Revision: 1577772
- new version 2.10
- disable python support for now
- update patches from ring-daemon

* Fri Feb 14 2020 umeabot <umeabot> 2.7.2-2.mga8
+ Revision: 1522151
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 21 2019 wally <wally> 2.7.2-1.mga7
+ Revision: 1358708
- new version 2.7.2 to fix CVE-2017-16872, CVE-2017-16875, CVE-2018-1000098, CVE-2018-1000099 (mga#22894)
- update gnutls and rfc6062 patches from ring-daemon

* Thu Oct 04 2018 umeabot <umeabot> 2.6-2.mga7
+ Revision: 1317378
- Mageia 7 Mass Rebuild

* Sun Jan 07 2018 wally <wally> 2.6-1.mga7
+ Revision: 1191341
- new version 2.6
- sync patches with Fedora and ring-daemon project
- add rfc6062 patch from ring-daemon project

* Sat Sep 16 2017 daviddavid <daviddavid> 2.5.5-7.mga7
+ Revision: 1154729
- rebuild for new gcc7

* Sat Aug 12 2017 daviddavid <daviddavid> 2.5.5-6.mga7
+ Revision: 1139890
- fix version of obsoleted python-pjsua

* Sat Aug 12 2017 daviddavid <daviddavid> 2.5.5-5.mga7
+ Revision: 1139884
- add and rediff upstream patch to fix CVE-2017-9359 and CVE-2017-9372 (mga#21505)
- rename python-pjsua to python2-pjsua

* Thu Jun 15 2017 pterjan <pterjan> 2.5.5-4.mga6
+ Revision: 1107738
- Fix a parallel build problem

* Mon Jan 02 2017 neoclust <neoclust> 2.5.5-3.mga6
+ Revision: 1079590
- Add pj_ice_strans_get_ice_sess function ( needed for ring-daemon)
- Add PJSIP_TRANSPORT_DTLS ( needed for ring-daemon)

* Sun Jan 01 2017 neoclust <neoclust> 2.5.5-1.mga6
+ Revision: 1079427
- New version 2.5.5

* Wed Apr 13 2016 daviddavid <daviddavid> 2.4.5-5.mga6
+ Revision: 1001039
- rebuild against libsrtp (srtp was removed)
- use new python macros
- include config_site.h file to improve performance from fedora
- add -DNDEBUG to CFLAGS at request of Asterisk developers from fedora

* Thu Mar 03 2016 umeabot <umeabot> 2.4.5-4.mga6
+ Revision: 983909
- Rebuild for openssl

* Tue Feb 16 2016 umeabot <umeabot> 2.4.5-3.mga6
+ Revision: 962102
- Mageia 6 Mass Rebuild

* Sun Nov 08 2015 daviddavid <daviddavid> 2.4.5-2.mga6
+ Revision: 899113
- remove nonexistent requires

* Sat Nov 07 2015 daviddavid <daviddavid> 2.4.5-1.mga6
+ Revision: 898483
- new version: 2.4.5
- create sub-packages for pjsua and python bindings
- fix endian support for aarch64
- add missing BuildRequires on speexdsp to fix build

* Sun Feb 08 2015 alien <alien> 2.3-1.mga5
+ Revision: 814093
- imported package pjproject

